@@ -12,11 +12,13 @@ class LanguageDefinition(BasePolarion):
 
     Attributes:
         language_definition_id (string)
-        label (string)
-"""
-    _cls_suds_map = {"language_definition_id": "id",
-                     "label": "label",
-                     "uri": "_uri",
-                     "_unresolved": "_unresolved"}
+        label (string)"""
+
+    _cls_suds_map = {
+        "language_definition_id": "id",
+        "label": "label",
+        "uri": "_uri",
+        "_unresolved": "_unresolved",
+    }
     _obj_client = "tracker_client"
     _obj_struct = "tns3:LanguageDefinition"
