@@ -19,20 +19,20 @@ class TestRunAttachment(BasePolarion):
         test_run_uri (SubterraURI)
         title (string)
         updated (dateTime)
-        url (string)
-"""
-    _cls_suds_map = {"author":
-                     {"field_name": "author",
-                      "cls": User},
-                     "filename": "fileName",
-                     "id": "id",
-                     "length": "length",
-                     "title": "title",
-                     "updated": "updated",
-                     "url": "url",
-                     "test_run_uri": "testRunURI",
-                     "_uri": "_uri",
-                     "_unresolvable": "_unresolvable"}
+        url (string)"""
+
+    _cls_suds_map = {
+        "author": {"field_name": "author", "cls": User},
+        "filename": "fileName",
+        "id": "id",
+        "length": "length",
+        "title": "title",
+        "updated": "updated",
+        "url": "url",
+        "test_run_uri": "testRunURI",
+        "_uri": "_uri",
+        "_unresolvable": "_unresolvable",
+    }
     _obj_client = "test_management_client"
     _obj_struct = "tns4:TestRunAttachment"
 
